@@ -1,14 +1,17 @@
 # coding=utf-8
-__version__ = "6.0.22"
+__version__ = "6.0.24"
 
 from subprocess import CalledProcessError, check_output
 import sys
 
 
 def check_no_incompatible():
-    cmd = ["pip", "list"]
+    cmd = ["pip3", "list"]
     try:
         res = check_output(cmd)
+    except FileNotFoundError:
+        msg = f"Cannot execute the command {cmd}"
+        sys.stderr.write(msg)
     except CalledProcessError:
         tb = traceback.format_exc()
         msg = f"Cannot get list of installed packages:\n\n{tb}"
